.wp-block-social-links {

	a:focus {
		color: var(--global--color-primary);
	}

	&.is-style-twentytwentyone-social-icons-color {

		a {
			color: var(--global--color-primary);
		}

		.wp-social-link,
		&.has-icon-background-color.has-icon-background-color .wp-social-link {
			background: none;
		}

	}
}
